@@ -1,5 +1,3 @@
 from libspn_keras.metrics.log_likelihood import LogLikelihood
 
-__all__ = [
-    'LogLikelihood'
-]
\ No newline at end of file
+__all__ = ["LogLikelihood"]
